@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/bin/sh
 
 dir=`dirname $0`
 suite="fail"
@@ -27,6 +27,11 @@ grep >/dev/null "tester_noshortdesc:Short_Description" $DOC_MODULE-undocumented.
 if test $? = 1 ; then failed=$(($failed + 1)); fi
 tested=$(($tested + 1))
 
+# check enums
+grep >/dev/null "EnumNoItemDocs (<items>)" $DOC_MODULE-undocumented.txt
+if test $? = 1 ; then failed=$(($failed + 1)); fi
+tested=$(($tested + 1))
+
 # summary
 rate=$((100*($tested - $failed)/$tested));
 echo "$rate %: Checks $tested, Failures: $failed"
